@@ -9,7 +9,6 @@
     :copyright: (c) 2014 by C. W.
     :license: GPL v3
 """
-
 from .book import (
     BookReader,
     Book,
@@ -23,6 +22,8 @@ from .sheets import (
     Reader,
     SeriesReader,
     ColumnSeriesReader,
+    load_from_dict,
+    load_from_records,
     load_from_memory,
     load_from_sql)
 from .utils import to_dict, to_array, to_records, dict_to_array, from_records
@@ -42,6 +43,10 @@ from .filters import (
     OddRowFilter,
     RowIndexFilter,
     SingleColumnFilter,
+    RowValueFilter,
+    NamedRowValueFilter,
+    ColumnValueFilter,
+    NamedColumnValueFilter,
     SingleRowFilter)
 from .cookbook import (
     merge_csv_to_a_book,
@@ -49,4 +54,4 @@ from .cookbook import (
     split_a_book,
     extract_a_sheet_from_a_book)
 
-__VERSION__ = '0.0.10'
+__VERSION__ = '0.1.1'
