@@ -7,10 +7,12 @@
     :copyright: (c) 2014 by C. W.
     :license: GPL v3
 """
+"""External presentation plugin register"""
 STRINGIFICATION = {}
 
 
 def outsource(func):
+    """Presentation injector"""
     def inner(self):
         plugin = STRINGIFICATION.get(str(self.__class__), None)
         if plugin:
