@@ -11,6 +11,8 @@ from .sheet import (
     Sheet,
     NominableSheet,
     load,
+    load_from_dict,
+    load_from_records,
     load_from_memory,
     load_from_sql,
     Reader,
