@@ -22,6 +22,7 @@ from ..iterators import (
     RowReverseIterator,
     ColumnReverseIterator
 )
+from ..filters import RowFilter, ColumnFilter
 from ..presentation import outsource
 
 
@@ -183,11 +184,97 @@ class Row:
     def __init__(self, matrix):
         self.ref = matrix
 
+    def select(self, indices):
+        """Delete row indices other than specified
+        
+        Examples:
+
+            >>> import pyexcel as pe
+            >>> data = [[1],[2],[3],[4],[5],[6],[7],[9]]
+            >>> sheet = pe.Sheet(data)
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+
+            | 1 |
+            +---+
+            | 2 |
+            +---+
+            | 3 |
+            +---+
+            | 4 |
+            +---+
+            | 5 |
+            +---+
+            | 6 |
+            +---+
+            | 7 |
+            +---+
+            | 9 |
+            +---+
+            >>> sheet.row.select([1,2,3,5])
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+
+            | 2 |
+            +---+
+            | 3 |
+            +---+
+            | 4 |
+            +---+
+            | 6 |
+            +---+
+
+        """
+        self.ref.filter(RowFilter(indices).invert())
+        
     def __delitem__(self, aslice):
-        """Override the operator to delete items"""
+        """Override the operator to delete items
+        
+        Examples:
+
+            >>> import pyexcel as pe
+            >>> data = [[1],[2],[3],[4],[5],[6],[7],[9]]
+            >>> sheet = pe.Sheet(data)
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+
+            | 1 |
+            +---+
+            | 2 |
+            +---+
+            | 3 |
+            +---+
+            | 4 |
+            +---+
+            | 5 |
+            +---+
+            | 6 |
+            +---+
+            | 7 |
+            +---+
+            | 9 |
+            +---+
+            >>> del sheet.row[1,2,3,5]
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+
+            | 1 |
+            +---+
+            | 5 |
+            +---+
+            | 7 |
+            +---+
+            | 9 |
+            +---+
+
+        """
         if isinstance(aslice, slice):
             my_range = _analyse_slice(aslice, self.ref.number_of_rows())
             self.ref.delete_rows(my_range)
+        elif isinstance(aslice, tuple):
+            self.ref.filter(RowFilter(list(aslice)))
+        elif isinstance(aslice, list):
+            self.ref.filter(RowFilter(aslice))
         else:
             self.ref.delete_rows([aslice])
 
@@ -270,14 +357,61 @@ class Column:
     def __init__(self, matrix):
         self.ref = matrix
 
+    def select(self, indices):
+        """
+        Examples:
+
+            >>> import pyexcel as pe
+            >>> data = [[1,2,3,4,5,6,7,9]]
+            >>> sheet = pe.Sheet(data)
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+---+---+---+---+---+---+---+
+            | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 9 |
+            +---+---+---+---+---+---+---+---+
+            >>> sheet.column.select([1,2,3,5])
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+---+---+---+
+            | 2 | 3 | 4 | 6 |
+            +---+---+---+---+
+        
+        """
+        self.ref.filter(ColumnFilter(indices).invert())
+        
     def __delitem__(self, aslice):
-        """Override the operator to delete items"""
+        """Override the operator to delete items
+
+        Examples:
+
+            >>> import pyexcel as pe
+            >>> data = [[1,2,3,4,5,6,7,9]]
+            >>> sheet = pe.Sheet(data)
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+---+---+---+---+---+---+---+
+            | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 9 |
+            +---+---+---+---+---+---+---+---+
+            >>> del sheet.column[1,2,3,5]
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+---+---+---+
+            | 1 | 5 | 7 | 9 |
+            +---+---+---+---+
+        
+        """
         if isinstance(aslice, slice):
             my_range = _analyse_slice(aslice, self.ref.number_of_columns())
             self.ref.delete_columns(my_range)
         elif isinstance(aslice, str):
             index = _excel_column_index(aslice)
             self.ref.delete_columns([index])
+        elif isinstance(aslice, tuple):
+            indices = list(aslice)
+            self.ref.filter(ColumnFilter(indices))
+        elif isinstance(aslice, list):
+            indices = aslice
+            self.ref.filter(ColumnFilter(indices))
         elif isinstance(aslice, int):
             self.ref.delete_columns([aslice])
         else:
@@ -950,6 +1084,7 @@ class Matrix(object):
 
     @outsource
     def __str__(self):
+        from ..formatters import to_format
         table = Texttable(max_width=0)
         table.set_chars(self.__border__())
         data = self.to_array()
@@ -959,6 +1094,6 @@ class Matrix(object):
                 if item == "":
                     new_array.append(" ")
                 else:
-                    new_array.append(item)
+                    new_array.append(to_format(str, item))
             table.add_row(new_array)
         return table.draw()
