@@ -15,7 +15,7 @@ from ..formatters import (
     RowFormatter,
     NamedColumnFormatter,
     NamedRowFormatter)
-from .._compact import is_string, OrderedDict, PY2
+from .._compact import is_string, OrderedDict, PY2, is_array_type
 from ..filters import ColumnIndexFilter, RowIndexFilter
 from ..iterators import ColumnIndexIterator, RowIndexIterator
 from ..presentation import outsource
@@ -90,9 +90,92 @@ class NamedRow(Row):
         >>> os.unlink("merged.csv")
 
     """
+    def select(self, names):
+        """Delete row indices other than specified
+        
+        Examples:
+
+            >>> import pyexcel as pe
+            >>> data = [[1],[2],[3],[4],[5],[6],[7],[9]]
+            >>> sheet = pe.Sheet(data)
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+
+            | 1 |
+            +---+
+            | 2 |
+            +---+
+            | 3 |
+            +---+
+            | 4 |
+            +---+
+            | 5 |
+            +---+
+            | 6 |
+            +---+
+            | 7 |
+            +---+
+            | 9 |
+            +---+
+            >>> sheet.row.select([1,2,3,5])
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+
+            | 2 |
+            +---+
+            | 3 |
+            +---+
+            | 4 |
+            +---+
+            | 6 |
+            +---+
+            >>> data = [
+            ...     ['a', 1],
+            ...     ['b', 1],
+            ...     ['c', 1]
+            ... ]
+            >>> sheet = pe.Sheet(data, name_rows_by_column=0)
+            >>> sheet.row.select(['a', 'b'])
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+---+
+            | a | 1 |
+            +---+---+
+            | b | 1 |
+            +---+---+
+
+        """
+        if is_array_type(names, str):
+            indices = names_to_indices(names, self.ref.rownames)
+            Row.select(self, indices)
+        else:
+            Row.select(self, names)
+
     def __delitem__(self, column_name):
+        """
+
+        Examples::
+
+            >>> import pyexcel as pe
+            >>> data = [
+            ...     ['a', 1],
+            ...     ['b', 1],
+            ...     ['c', 1]
+            ... ]
+            >>> sheet = pe.Sheet(data, name_rows_by_column=0)
+            >>> del sheet.row['a', 'b']
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+---+
+            | c | 1 |
+            +---+---+
+
+        """
         if is_string(type(column_name)):
             self.ref.delete_named_row_at(column_name)
+        elif isinstance(column_name, tuple) and is_array_type(list(column_name), str):
+            indices = names_to_indices(list(column_name), self.ref.rownames)
+            Row.__delitem__(self, indices)
         else:
             Row.__delitem__(self, column_name)
 
@@ -164,9 +247,94 @@ class NamedColumn(Column):
         print(r.column["column 1"])
 
     """
+    def select(self, names):
+        """Delete columns other than specified
+        
+        Examples:
+     
+            >>> import pyexcel as pe
+            >>> data = [[1,2,3,4,5,6,7,9]]
+            >>> sheet = pe.Sheet(data)
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+---+---+---+---+---+---+---+
+            | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 9 |
+            +---+---+---+---+---+---+---+---+
+            >>> sheet.column.select([1,2,3,5])
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+---+---+---+
+            | 2 | 3 | 4 | 6 |
+            +---+---+---+---+
+            >>> data = [
+            ...     ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h'],
+            ...     [1,2,3,4,5,6,7,9],
+            ... ]
+            >>> sheet = pe.Sheet(data, name_columns_by_row=0)
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+---+---+---+---+---+---+---+
+            | a | b | c | d | e | f | g | h |
+            +===+===+===+===+===+===+===+===+
+            | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 9 |
+            +---+---+---+---+---+---+---+---+
+            >>> del sheet.column['a', 'b', 'i', 'f'] # doctest:+ELLIPSIS
+            Traceback (most recent call last):
+                ...
+            ValueError: ...
+            >>> sheet.column.select(['a', 'c', 'e', 'h'])
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+---+---+---+
+            | a | c | e | h |
+            +===+===+===+===+
+            | 1 | 3 | 5 | 9 |
+            +---+---+---+---+
+
+        """
+        if is_array_type(names, str):
+            indices = names_to_indices(names, self.ref.colnames)
+            Column.select(self, indices)
+        else:
+            Column.select(self, names)
+
     def __delitem__(self, str_or_aslice):
+        """
+
+        Example::
+
+            >>> import pyexcel as pe
+            >>> data = [
+            ...     ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h'],
+            ...     [1,2,3,4,5,6,7,9],
+            ... ]
+            >>> sheet = pe.Sheet(data, name_columns_by_row=0)
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+---+---+---+---+---+---+---+
+            | a | b | c | d | e | f | g | h |
+            +===+===+===+===+===+===+===+===+
+            | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 9 |
+            +---+---+---+---+---+---+---+---+
+            >>> del sheet.column['a', 'b', 'i', 'f'] # doctest:+ELLIPSIS
+            Traceback (most recent call last):
+                ...
+            ValueError: ...
+            >>> del sheet.column['a', 'c', 'e', 'h']
+            >>> sheet
+            Sheet Name: pyexcel
+            +---+---+---+---+
+            | b | d | f | g |
+            +===+===+===+===+
+            | 2 | 4 | 6 | 7 |
+            +---+---+---+---+
+
+        """
         if is_string(type(str_or_aslice)):
             self.ref.delete_named_column_at(str_or_aslice)
+        elif isinstance(str_or_aslice, tuple) and is_array_type(list(str_or_aslice), str):
+            indices = names_to_indices(list(str_or_aslice), self.ref.colnames)
+            Column.__delitem__(self, indices)
         else:
             Column.__delitem__(self, str_or_aslice)
 
@@ -603,6 +771,7 @@ class NominableSheet(FilterableSheet):
 
     @outsource
     def __str__(self):
+        from ..formatters import to_format
         ret = "Sheet Name: %s\n" % self.name
         if len(self.colnames) > 0:
             table = Texttable(max_width=0)
@@ -615,7 +784,7 @@ class NominableSheet(FilterableSheet):
                     if item == "":
                         new_array.append(" ")
                     else:
-                        new_array.append(item)
+                        new_array.append(to_format(str,item))
                 new_data.append(new_array)
             table.add_rows(new_data)
             return ret+table.draw()
